package com.sun.media.sound;

import javax.sound.sampled.AudioInputStream;
import java.io.FileInputStream;
import java.io.File;
import java.io.BufferedInputStream;
import java.net.URL;
import java.io.IOException;
import javax.sound.sampled.UnsupportedAudioFileException;
import javax.sound.sampled.AudioFormat;
import java.io.DataInputStream;
import javax.sound.sampled.AudioFileFormat;
import java.io.InputStream;

public final class AuFileReader extends SunFileReader
{
    public AuFileReader() {
    }
    
    @Override
    public AudioFileFormat getAudioFileFormat(InputStream in) throws UnsupportedAudioFileException, IOException {
        int readlimit = 28;
        boolean bigEndian = false;
        int n = 0;
        DataInputStream dataInputStream = new DataInputStream(in);
        dataInputStream.mark(readlimit);
        int int1 = dataInputStream.readInt();
        if (int1 != 779316836 || int1 == 779314176 || int1 == 1684960046 || int1 == 6583086) {
            dataInputStream.reset();
            throw new UnsupportedAudioFileException("not an AU file");
        }
        if (int1 == 779316836 || int1 == 779314176) {
            bigEndian = true;
        }
        int n2 = bigEndian ? dataInputStream.readInt() : this.rllong(dataInputStream);
        n += 4;
        int n3 = bigEndian ? dataInputStream.readInt() : this.rllong(dataInputStream);
        n += 4;
        int n4 = bigEndian ? dataInputStream.readInt() : this.rllong(dataInputStream);
        n += 4;
        int n5 = bigEndian ? dataInputStream.readInt() : this.rllong(dataInputStream);
        n += 4;
        int channels = bigEndian ? dataInputStream.readInt() : this.rllong(dataInputStream);
        n += 4;
        if (channels <= 0) {
            dataInputStream.reset();
            throw new UnsupportedAudioFileException("Invalid number of channels");
        }
        AudioFormat.Encoding encoding;
        int sampleSizeInBits;
        switch (n4) {
            case 1: {
                encoding = AudioFormat.Encoding.ULAW;
                sampleSizeInBits = 8;
                break;
            }
            case 27: {
                encoding = AudioFormat.Encoding.ALAW;
                sampleSizeInBits = 8;
                break;
            }
            case 2: {
                encoding = AudioFormat.Encoding.PCM_SIGNED;
                sampleSizeInBits = 8;
                break;
            }
            case 3: {
                encoding = AudioFormat.Encoding.PCM_SIGNED;
                sampleSizeInBits = 16;
                break;
            }
            case 4: {
                encoding = AudioFormat.Encoding.PCM_SIGNED;
                sampleSizeInBits = 24;
                break;
            }
            case 5: {
                encoding = AudioFormat.Encoding.PCM_SIGNED;
                sampleSizeInBits = 32;
                break;
            }
            default: {
                dataInputStream.reset();
                throw new UnsupportedAudioFileException("not a valid AU file");
            }
        }
        int calculatePCMFrameSize = SunFileReader.calculatePCMFrameSize(sampleSizeInBits, channels);
        int n6;
        if (n3 < 0) {
            n6 = -1;
        }
        else {
            n6 = n3 / calculatePCMFrameSize;
        }
        AuFileFormat o = new AuFileFormat(AudioFileFormat.Type.AU, n3 + n2, new AudioFormat(encoding, (float)n5, sampleSizeInBits, channels, calculatePCMFrameSize, (float)n5, (boolean)bigEndian), n6);
        dataInputStream.reset();
        return o;
    }
    
    @Override
    public AudioFileFormat getAudioFileFormat(URL url) throws UnsupportedAudioFileException, IOException {
        AudioFileFormat audioFileFormat = null;
        InputStream openStream = url.openStream();
        try {
            audioFileFormat = this.getAudioFileFormat(new BufferedInputStream(openStream, 4096));
        }
        finally {
            openStream.close();
        }
        return audioFileFormat;
    }
    
    @Override
    public AudioFileFormat getAudioFileFormat(File file) throws UnsupportedAudioFileException, IOException {
        AudioFileFormat audioFileFormat = null;
        FileInputStream in = new FileInputStream(file);
        try {
            audioFileFormat = this.getAudioFileFormat(new BufferedInputStream(in, 4096));
        }
        finally {
            in.close();
        }
        return audioFileFormat;
    }
    
    @Override
    public AudioInputStream getAudioInputStream(InputStream in) throws UnsupportedAudioFileException, IOException {
        AudioFileFormat audioFileFormat = this.getAudioFileFormat(in);
        AudioFormat format = audioFileFormat.getFormat();
        DataInputStream stream = new DataInputStream(in);
        stream.readInt();
        stream.skipBytes((format.isBigEndian() ? stream.readInt() : this.rllong(stream)) - 8);
        return new AudioInputStream(stream, format, (long)audioFileFormat.getFrameLength());
    }
    
    @Override
    public AudioInputStream getAudioInputStream(URL url) throws UnsupportedAudioFileException, IOException {
        InputStream openStream = url.openStream();
        AudioInputStream audioInputStream = null;
        try {
            audioInputStream = this.getAudioInputStream(new BufferedInputStream(openStream, 4096));
        }
        finally {
            if (audioInputStream == null) {
                openStream.close();
            }
        }
        return audioInputStream;
    }
    
    @Override
    public AudioInputStream getAudioInputStream(File file) throws UnsupportedAudioFileException, IOException {
        FileInputStream in = new FileInputStream(file);
        AudioInputStream audioInputStream = null;
        try {
            audioInputStream = this.getAudioInputStream(new BufferedInputStream(in, 4096));
        }
        finally {
            if (audioInputStream == null) {
                in.close();
            }
        }
        return audioInputStream;
    }
}
